@@ -1,12 +1,6 @@
 package Mesos::Types;
 use strict;
 use warnings;
-use Mesos::Messages;
-use Module::Runtime qw();
-use Type::Library
-   -base;
-use Types::Standard -types;
-use Type::Utils -all;
 
 =head1 NAME
 
@@ -20,11 +14,15 @@ Coercions are also provided for message classes, from hash ref constructors.
 
 =cut
 
+use Type::Library
+   -base;
+use Type::Utils -all;
+use Types::Standard -types;
+use Mesos::Messages;
+
 my @messages = qw(
-    CommandInfo
     Credential
     ExecutorID
-    ExecutorInfo
     Filters
     FrameworkInfo
     OfferID
@@ -39,28 +37,13 @@ for my $message (@messages) {
     my $protobuf_class = "Mesos::$message";
     class_type $message, {class => $protobuf_class};
     coerce $message,
-        from HashRef, "$protobuf_class->new(\$_)";
+        from HashRef, via { $protobuf_class->new($_) };
 }
 
-class_type "Async::Interrupt";
-declare $_, as InstanceOf["Mesos::$_"] for qw(
-    Channel
-    Dispatcher
-    Executor
-    ExecutorDriver
-    Scheduler
-    SchedulerDriver
-);
+role_type  $_, {role => "Mesos::Role::$_"} for qw(Scheduler       Executor);
+class_type $_, {class => "Mesos::$_"}      for qw(SchedulerDriver ExecutorDriver Channel);
 
-coerce "Dispatcher",
-    from Str, <<'__END__';
-do {
-    my $class = $_;
-    $class = "Mesos::Dispatcher::$class" unless $class =~ s/^\+//;
-    Module::Runtime::require_module($class);
-    $class->new;
-}
-__END__
 
 __PACKAGE__->meta->make_immutable;
+
 1;
